# API reference

::: slp.config.config_parser
::: slp.config.nlp
::: slp.config.omegaconf

::: slp.data.collators
::: slp.data.corpus
::: slp.data.datasets
::: slp.data.transforms

::: slp.modules.attention
::: slp.modules.classifier
::: slp.modules.embed
::: slp.modules.feedforward
::: slp.modules.norm
::: slp.modules.regularization
::: slp.modules.rnn
::: slp.modules.transformer


::: slp.plbind.dm
::: slp.plbind.helpers
::: slp.plbind.module
::: slp.plbind.trainer


::: slp.util.log
::: slp.util.pytorch
::: slp.util.system
::: slp.util.types
